<?php
/**
 * Plugin Name: Webstribe IG Social Feed
 * Plugin URI: https://softstribe.com/
 * Description: Display Instagram feeds with filters and multiple layouts.
 * Version: 1.0.0
 * Author: Muhammad Dilawar
 * Author URI: https://webstribe.com/
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: webstribe-ig-social-feed
 */
 
 
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class Custom_Instagram_Feed {

    public function __construct() {
        add_action('admin_menu', [$this, 'add_plugin_menu']);
        add_action('admin_init', [$this, 'register_settings']);
        add_shortcode('custom_instagram_feed', [$this, 'display_feed']);
        add_action('wp_enqueue_scripts', [$this, 'enqueue_styles']);
    }

    public function add_plugin_menu() {
        add_options_page('Instagram Feed Settings', 'Instagram Feed', 'manage_options', 'custom-instagram-feed', [$this, 'settings_page']);
    }

    public function register_settings() {
        register_setting('custom_instagram_feed_settings', 'feed_layout');
        register_setting('custom_instagram_feed_settings', 'instagram_token');
        register_setting('custom_instagram_feed_settings', 'feed_limit');
    }

     public function settings_page() {
        ?>
        <div class="wrap">
            <h1>Instagram Feed Settings</h1>
            <form method="post" action="options.php">
                <?php settings_fields('custom_instagram_feed_settings'); ?>
                <table class="form-table">
                    <tr>
                        <th scope="row">Instagram Token</th>
                        <td>
                            <input type="text" name="instagram_token" value="<?php echo esc_attr(get_option('instagram_token')); ?>" class="regular-text">
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">Feed Layout</th>
                        <td>
                            <select name="feed_layout">
                                <option value="grid" <?php selected(get_option('feed_layout'), 'grid'); ?>>Grid</option>
                                <option value="masonry" <?php selected(get_option('feed_layout'), 'masonry'); ?>>Masonry</option>
                                <option value="columns" <?php selected(get_option('feed_layout'), 'columns'); ?>>Columns</option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">Feed Limit</th>
                        <td>
                            <input type="number" name="feed_limit" value="<?php echo esc_attr(get_option('feed_limit', 10)); ?>" class="small-text">
                        </td>
                    </tr>
                </table>
                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }

    public function fetch_instagram_feed() {
    $token = get_option('instagram_token');
    $limit = get_option('feed_limit', 10);
    // Add "children{media_url,media_type}" to fetch carousel items
    $url = "https://graph.instagram.com/me/media?fields=id,media_type,media_url,caption,permalink,children{media_url,media_type}&limit={$limit}&access_token=" . $token;

    $response = wp_remote_get($url);

    if (is_wp_error($response)) {
        return [];
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    return $data['data'] ?? [];
}

    public function enqueue_styles() {
        wp_enqueue_style('custom-instagram-feed', plugins_url('style.css', __FILE__));
    }

    public function display_feed($atts) {
    $layout = get_option('feed_layout', 'grid');
    $posts = $this->fetch_instagram_feed();
    ob_start();
    ?>
    <div class="instagram-feed-wrapper">
        <!-- Filters at the top -->
        <div class="instagram-feed-filters">
            <button class="filter-button active" data-filter="all">All</button>
            <button class="filter-button" data-filter="image">Photos</button>
            <button class="filter-button" data-filter="video">Videos</button>
            <button class="filter-button" data-filter="carousel_album">Gallery</button>
        </div>

        <div class="custom-instagram-feed <?php echo esc_attr($layout); ?>">
            <?php if (!empty($posts)) {
                foreach ($posts as $post) {
                    $media_type = strtolower($post['media_type']);
                    echo '<div class="instagram-post" data-type="' . esc_attr($media_type) . '">';
                    
                    // Handle Carousel Albums
                    if ($media_type === 'carousel_album') {
                        echo '<div class="carousel-container">';
                        // Display all child media items
                        if (!empty($post['children']['data'])) {
                            foreach ($post['children']['data'] as $index => $child) {
                                $active = $index === 0 ? 'active' : '';
                                echo '<div class="carousel-slide ' . $active . '">';
                                if ($child['media_type'] === 'IMAGE') {
                                    echo '<img src="' . esc_url($child['media_url']) . '" alt="Gallery Image">';
                                } elseif ($child['media_type'] === 'VIDEO') {
                                    echo '<video controls><source src="' . esc_url($child['media_url']) . '" type="video/mp4"></video>';
                                }
                                echo '</div>';
                            }
                        }
                        // Navigation Arrows
                        echo '<div class="carousel-controls">';
                        echo '<button class="carousel-prev">‹</button>';
                        echo '<button class="carousel-next">›</button>';
                        echo '</div>';
                        echo '</div>'; // .carousel-container
                    } else {
                        // Regular image/video (existing code)
                        echo '<a href="' . esc_url($post['permalink']) . '" target="_blank">';
                        if ($post['media_type'] === 'IMAGE') {
                            echo '<img src="' . esc_url($post['media_url']) . '" alt="' . esc_attr($post['caption'] ?? '') . '">';
                        } elseif ($post['media_type'] === 'VIDEO') {
                            echo '<video controls><source src="' . esc_url($post['media_url']) . '" type="video/mp4"></video>';
                        }
                        echo '</a>';
                    }
                    echo '</div>'; // .instagram-post
                }
            } else {
                echo '<p>No Instagram posts found.</p>';
            } ?>
        </div>
    </div>


    <!-- JavaScript for filtering -->
    <script>
    document.addEventListener("DOMContentLoaded", function() {
        // Filter functionality
        document.querySelectorAll(".filter-button").forEach(button => {
            button.addEventListener("click", function() {
                // Remove active class from all buttons
                document.querySelectorAll(".filter-button").forEach(btn => btn.classList.remove("active"));
                // Add active class to clicked button
                this.classList.add("active");
                
                const filter = this.getAttribute("data-filter");
                const posts = document.querySelectorAll(".instagram-post");
                
                posts.forEach(post => {
                    const type = post.getAttribute("data-type");
                    if (filter === "all" || type === filter) {
                        post.style.display = "block";
                    } else {
                        post.style.display = "none";
                    }
                });
            });
        });
    });
    </script>
    
<script>
document.addEventListener("DOMContentLoaded", function() {
    // Initialize carousels
    document.querySelectorAll('.carousel-container').forEach(carousel => {
        const slides = carousel.querySelectorAll('.carousel-slide');
        let currentSlide = 0;
        const prevButton = carousel.querySelector('.carousel-prev');
        const nextButton = carousel.querySelector('.carousel-next');

        // Show first slide initially
        slides[currentSlide].classList.add('active');

        // Next Button Click
        nextButton.addEventListener('click', () => {
            slides[currentSlide].classList.remove('active');
            currentSlide = (currentSlide + 1) % slides.length;
            slides[currentSlide].classList.add('active');
        });

        // Previous Button Click
        prevButton.addEventListener('click', () => {
            slides[currentSlide].classList.remove('active');
            currentSlide = (currentSlide - 1 + slides.length) % slides.length;
            slides[currentSlide].classList.add('active');
        });
    });
});
</script>
    <?php
    return ob_get_clean();
}
}

new Custom_Instagram_Feed();